﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

//////////////////////////////////////////////////////////////////
//【敵（サソリ）のコントロールに使用するクラス】
// 敵をX方向にランダムな距離のジャンプ攻撃、ランダムな方向にジャンプ
// ランダムなタイミングにジャンプ、ゲーム終了時に動きを止める
//////////////////////////////////////////////////////////////////
public class EnemyController : MonoBehaviour
{
    /////////////////////////////////
    // 【変数の設定】
    /////////////////////////////////

    //【Unity Editorから設定するPublic変数】
    public Rigidbody2D rigidBody;  // Rigidbody2Dコンポーネント呼び出し用

    //【このプログラム内で使用するPrivate変数】
    private GameController class_GameController;  // GameController呼び出し用

    private float time;  // 経過残時間カウントダウン用の変数


    /////////////////////////////////
    // 【関数の設定】
    /////////////////////////////////

    //【ゲーム開始時に１回だけ動く関数】
    //（Unityの標準関数）
    void Start()
    {
        // Scene上のGameControllerからGameControllerコンポーネントを取得
        class_GameController =
            GameObject.Find("GameController").GetComponent<GameController>();

        // 経過残時間の初期値を取得
        time = Random.Range(2.5f, 4.0f);
    }


    //【毎フレームに１度動く関数】
    //（Unityの標準関数）
    void Update()
    {
        // GameControllerが持つゲーム終了を管理する変数がtrueの場合
        // (ゲームが終了している場合)
        if (class_GameController.stopGame)
        {
            // 敵のRigidbody2Dコンポーネントを削除して重力が働かなくする
            Destroy(rigidBody);

            // これ以降の敵の動きの処理を実行させない
            return;
        }

        // フレーム単位に経過残時間をカウントダウンする
        time -= Time.deltaTime;

        // 経過残時間が0を切った場合
        if (time < 0)
        {
            // 敵のジャンプ力をランダムに設定
            float jump_Force = Random.Range(4.0f, 7.5f);
            float direction;  // 敵のジャンプする方向の変数定義

            // 敵のジャンプする方向をランダムに設定
            if (Random.value > 0.5)
                direction = 1;  // 敵を右にジャンプ
            else
                direction = -1;  // 敵を左にジャンプ

            // 敵の画像を方向変数の方向に向ける
            transform.localScale = new Vector3(0.1f * direction, 0.1f, 1);

            // 敵をランダムな方向/距離でジャンプをさせる力を瞬間的にかける
            rigidBody.AddForce(new Vector3(0.8f * direction, 1, 0) * jump_Force,
                ForceMode2D.Impulse);

            // 次のジャンプをするタイミングのランダム値を取得
            time = Random.Range(2.5f, 4.0f);
        }
    }
}
