﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

//////////////////////////////////////////////////////////////////
//【攻撃の炎のコントロールに使用するクラス】
// 炎をX方向移動、一定距離で消滅、敵との当たりで自分と相手を消滅
//////////////////////////////////////////////////////////////////
public class FireController : MonoBehaviour
{
    /////////////////////////////////
    // 【変数の設定】
    /////////////////////////////////

    //【定数の設定】（レベル設計で変更可能）
    const float FIRE_DISTANCE = 3;  // 炎が消滅するまでの距離

    //【Unity Editorから設定するPublic変数】
    // 右方向と左方向に進む2種類のPrefabを作成するためPublic化
    public float fire_Speed = 0.05f;  // X方向に進む速度

    //【このプログラム内で使用するPrivate変数】 
    private Vector3 start_Position;  // 炎の進行距離計算用の初期位置


    /////////////////////////////////
    // 【関数の設定】
    /////////////////////////////////

    //【ゲーム開始時に１回だけ動く関数】
    //（Unityの標準関数）
    void Start()
    {
        // 炎の初期位置を取得
        start_Position = transform.position;
    }


    //【毎フレームに１度動く関数】
    //（Unityの標準関数）
    void Update()
    {
        // 炎のX方向への進行距離を取得
        // 現在位置-初期位置の絶対値を計算
        float distance =
            Mathf.Abs(transform.position.x - start_Position.x);

        // 炎の進行距離が消滅するまでの距離を越えた場合
        if (distance > FIRE_DISTANCE)
        {
            // 炎を消滅させる
            Destroy(this.gameObject);
        }

        // 炎をX方向に速度の値だけ移動させる
        transform.Translate(fire_Speed, 0f, 0f);
    }


    //【炎のコライダーが他のコライダーに衝突した場合呼ばれる関数】
    //（Unityの標準関数）
    private void OnCollisionEnter2D(Collision2D collision)
    {
        // 衝突した相手のゲームオブジェクトのタグがEnemy（敵）の場合
        if (collision.gameObject.tag == "Enemy")
        {
            // 相手の敵を消滅させる
            Destroy(collision.gameObject);

            // 炎を消滅させる
            Destroy(this.gameObject);
        }
    }
}
