﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

//////////////////////////////////////////////////////////////////
//【Playerのコントロールに使用するクラス】
// キーボード入力で移動/ジャンプ/攻撃、ゲーム終了時は停止、攻撃サウンド
// Playerの衝突や通過処理を実行、攻撃として炎を発射、アニメーション制御
//////////////////////////////////////////////////////////////////
public class PlayerController : MonoBehaviour
{
    /////////////////////////////////
    // 【変数の設定】
    /////////////////////////////////

    //【定数の設定】（レベル設計で変更可能）
    const float WALK_FORCE = 11;  // 横に進む時にかける力の強さ
    const float JUMP_FORCE = 6;  // ジャンプ時にかける力の強さ
    const float MAX_WALK_SPEED = 1.8f;  // 横に進む速度の最大値
    //（横方向に力をかけ続けると速くなり過ぎるため最大値を設定）

    //【Unity Editorから設定するPublic変数】
    public GameController class_GameController;  // GameController呼び出し用

    public Rigidbody2D rigidBody;  // Rigidbody2Dコンポーネント呼び出し用
    public GameObject fire_Right;  // 右向きの攻撃の炎のPrefab
    public GameObject fire_Left;  // 左向きの攻撃の炎のPrefab


    /////////////////////////////////
    // 【関数の設定】
    /////////////////////////////////

    //【毎フレームに１度動く関数】
    //（Unityの標準関数）
    void Update()
    {
        // GameControllerが持つゲーム終了を管理する変数がtrueの場合
        // (ゲームが終了している場合)
        if (class_GameController.stopGame)
        {
            // PlayerのRigidbody2Dコンポーネントを削除して重力が働かなくする
            Destroy(rigidBody);

            // これ以降のPlayerの動きの処理を実行させない
            return;
        }

        // 上矢印キーが押された場合
        if (Input.GetKeyDown(KeyCode.UpArrow))
        {
            // Playerに上向きの力を瞬間的にかける
            rigidBody.AddForce(transform.up * JUMP_FORCE, ForceMode2D.Impulse);
        }

        int direction = 0;  // 歩く方向の変数定義
        // 右矢印キーが押された場合、方向変数を右(1)に
        if (Input.GetKey(KeyCode.RightArrow)) direction = 1;
        // 左矢印キーが押された場合、方向変数を左(-1)に
        if (Input.GetKey(KeyCode.LeftArrow)) direction = -1;

        // Playerの現在のX方向の速度を取得
        float speedx = Mathf.Abs(rigidBody.velocity.x);

        // X方向の速度が既定最大値より小さい場合
        if (speedx < MAX_WALK_SPEED)
        {
            // Playerに方向変数の方向に力をかける
            rigidBody.AddForce(transform.right * direction * WALK_FORCE);
        }

        // 方向変数が0でない場合
        if (direction != 0)
        {
            // Playerの画像を方向変数の方向に向ける
            transform.localScale = new Vector3(0.1f * direction, 0.1f, 1);
        }

        // スペースキーが押された場合
        if (Input.GetKeyDown(KeyCode.Space))
        {
            // Playerの画像が右を向いている場合
            if (transform.localScale.x > 0)
            {
                // 右向きの攻撃の炎をScene上に生成する
                Instantiate(fire_Right, transform.position, Quaternion.identity);
            }
            else
            {
                // 左向きの攻撃の炎をScene上に生成する
                Instantiate(fire_Left, transform.position, Quaternion.identity);
            }
        }
    }


    //【Playerのコライダーが他のコライダーに衝突した場合呼ばれる関数】
    //（Unityの標準関数）
    private void OnCollisionEnter2D(Collision2D collision)
    {
        // 衝突した相手のゲームオブジェクトのタグがEnemy(敵)の場合
        if (collision.gameObject.tag == "Enemy")
        {
            // GameControllerのゲームオーバー処理を呼ぶ
            class_GameController.On_GameOver();
        }
    }


    //【Playerのコライダーが他のコライダーを通過した場合呼ばれる関数】
    //（Unityの標準関数）
    private void OnTriggerEnter2D(Collider2D collision)
    {
        // 通過した相手のゲームオブジェクトのタグがDoor(ドア)の場合
        if (collision.gameObject.tag == "Door")
        {
            // GameControllerのゲームクリア処理を呼ぶ
            class_GameController.On_GameClear();
        }
    }
}
